Crate raps_admin

Crate raps_admin 

Account Admin Bulk Management

This crate provides bulk user management capabilities for ACC/BIM 360 accounts:

  • Add users to multiple projects in a single operation
  • Remove users from multiple projects
  • Update user roles across projects
  • Manage folder-level permissions

Features:

  • Configurable concurrency with rate limit handling
  • Progress tracking with callbacks
  • State persistence for resumable operations
  • Retry logic with exponential backoff

Re-exports

pub use bulk::executor::BulkConfig;
pub use bulk::executor::BulkExecutor;
pub use bulk::executor::BulkOperationResult;
pub use bulk::executor::ItemDetail;
pub use bulk::executor::ItemResult;
pub use bulk::executor::ProcessItem;
pub use bulk::executor::ProgressUpdate;
pub use bulk::state::OperationState;
pub use bulk::state::OperationSummary;
pub use bulk::state::StateManager;
pub use bulk::state::StateUpdate;
pub use error::AdminError;
pub use error::ExitCode;
pub use filter::ProjectFilter;
pub use operations::BulkAddUserParams;
pub use operations::BulkRemoveUserParams;
pub use operations::BulkUpdateFolderRightsParams;
pub use operations::BulkUpdateRoleParams;
pub use operations::bulk_add_user;
pub use operations::bulk_remove_user;
pub use operations::bulk_update_folder_rights;
pub use operations::bulk_update_role;
pub use operations::resume_bulk_add_user;
pub use operations::resume_bulk_remove_user;
pub use operations::resume_bulk_update_folder_rights;
pub use operations::resume_bulk_update_role;
pub use types::FolderType;
pub use types::OperationStatus;
pub use types::OperationType;
pub use types::PermissionLevel;

Modules

bulk
Bulk operation orchestration module
error
Error types for bulk admin operations
filter
Project filter for selecting target projects
operations
Specific bulk operation implementations
report
Result reporting and export functionality
types
Core types for bulk admin operations